#ifndef WAVEFORMLABEL_H
#define WAVEFORMLABEL_H

#include "thumbnaillabel.h"

class WaveformLabel : public ThumbnailLabel
{
    Q_OBJECT

public:
    explicit WaveformLabel(QWidget *parent = 0);

protected:
    void mousePressEvent(QMouseEvent *event);
    void mouseReleaseEvent(QMouseEvent *event);
    void leaveEvent(QEvent *event);
    void paintEvent(QPaintEvent *event);
};

#endif // WAVEFORMLABEL_H
